#! /usr/bin/env python3
import os
import sys
from pathlib import Path

import click
from sqlalchemy import create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker

from schmeckels import autosort, importer, info, models, restart, serve, sort, stats, validate
from schmeckels.helper import build_database_filename, build_rules_filename, get_data_dir

__version__ = "0.0.1"


@click.group()
def cli():
    pass


@cli.command(name="init")
def init():
    data_dir = get_data_dir()

    # make sure folder exists
    try:
        os.mkdir(data_dir)
    except FileExistsError:
        pass

    db_path = build_database_filename(data_dir)
    rule_path = build_rules_filename(data_dir)

    if os.path.exists(db_path) or os.path.exists(rule_path):
        print(f"Init already ran")
        sys.exit(1)
    else:
        # database
        engine = create_engine(f"sqlite:///{db_path}")
        models.Base.metadata.create_all(engine)
        # rules
        Path(rule_path).touch()

        print(f"Sucessfull init at {data_dir}'")


def main():
    cli.add_command(sort.command)
    cli.add_command(importer.command)
    cli.add_command(serve.command)
    cli.add_command(autosort.command)
    cli.add_command(validate.command)
    cli.add_command(info.command)
    cli.add_command(stats.command)
    cli.add_command(restart.command)
    cli()
