#! /usr/bin/env python3
import sys

import click
import colorful as cf
from sqlalchemy import create_engine, desc
from sqlalchemy.orm import sessionmaker

from schmeckels import banks
from schmeckels.helper import get_session, import_transactions
from schmeckels.models import Transaction


@click.command(name="import")
@click.option("--filetype", "-t", type=click.Choice([b[0] for b in banks.SUPPORTED_BANKS], case_sensitive=False))
@click.option("--dry-run", default=False, is_flag=True)
@click.argument("filename", type=click.Path(exists=True))
def command(filetype, dry_run, filename):
    session = get_session()
    new = import_transactions(session, filetype, filename)

    if dry_run:
        print(cf.yellow(f"Would have imported {len(new)} new transactions"))
    else:
        if len(new) > 0:
            session.bulk_save_objects(new)
            session.commit()
        print(cf.green(f"Imported {len(new)} new transactions"))
